## 🛡️ Security Policy

### Reporting a Vulnerability

If you discover a potential security issue or vulnerability in this software, **please do not create a public issue**.

Instead, kindly report it privately by sending an [email 📧](nabbisen@scqr.net])

We will do our best to assess and respond in a timely manner, but please understand that this project is maintained voluntarily in free time. Thank you for your understanding and responsible disclosure.

### Supported Versions

This project is currently maintained as a best-effort activity. Only the latest version is considered to receive potential fixes.
